=========================
 Invenio-PIDStore v0.1.3
=========================

Invenio-PIDStore v0.1.3 was released on October 11, 2015.

About
-----

Invenio module that stores and registers persistent identifiers.

*This is an experimental development preview release.*

Improved features
-----------------

- Makes Datacite provider optional.

Installation
------------

   $ pip install invenio-pidstore==0.1.3

Documentation
-------------

   http://invenio-pidstore.readthedocs.org/en/v0.1.3

Happy hacking and thanks for flying Invenio-PIDStore.

| Invenio Development Team
|   Email: info@invenio-software.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-pidstore
|   URL: http://invenio-software.org
